==> haskell-data-array-byte-0.1.0.1-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-array-byte.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-array-byte
version:              0.1.0.1
visibility:           public
id:                   data-array-byte-0.1.0.1-IF8Rfu0RHop768CiMVoPta
key:                  data-array-byte-0.1.0.1-IF8Rfu0RHop768CiMVoPta
license:              BSD-3-Clause
copyright:            (c) Roman Leshchinskiy 2009-2012
maintainer:           andrew.lelechenko@gmail.com
author:               Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage:             https://github.com/Bodigrim/data-array-byte
synopsis:             Compatibility layer for Data.Array.Byte
description:
    Compatibility layer for [Data.Array.Byte](https://hackage.haskell.org/package/base/docs/Data-Array-Byte.html), providing boxed wrappers for @ByteArray#@ and @MutableByteArray#@ and relevant instances for GHC < 9.4. Include it into your Cabal file:

    > build-depends: base
    > if impl(ghc < 9.4)
    >   build-depends: data-array-byte

    and then @import Data.Array.Byte@ unconditionally.

category:             Compatibility
abi:                  0f95fc1c1d8ee93834dbbe8b6753f4d5
exposed:              True
exposed-modules:      Data.Array.Byte
import-dirs:          /usr/lib/ghc-9.0.2/site-local/data-array-byte-0.1.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/data-array-byte-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-array-byte
hs-libraries:         HSdata-array-byte-0.1.0.1-IF8Rfu0RHop768CiMVoPta
depends:
    base-4.15.1.0 deepseq-1.4.5.0 template-haskell-2.17.0.0

haddock-interfaces:
    /usr/share/doc/haskell-data-array-byte/html/data-array-byte.haddock

haddock-html:         /usr/share/doc/haskell-data-array-byte/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-array-byte-0.1.0.1-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-array-byte.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-array-byte
version:              0.1.0.1
visibility:           public
id:                   data-array-byte-0.1.0.1-71m0qUbz0GPK2XPFn43oUy
key:                  data-array-byte-0.1.0.1-71m0qUbz0GPK2XPFn43oUy
license:              BSD-3-Clause
copyright:            (c) Roman Leshchinskiy 2009-2012
maintainer:           andrew.lelechenko@gmail.com
author:               Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage:             https://github.com/Bodigrim/data-array-byte
synopsis:             Compatibility layer for Data.Array.Byte
description:
    Compatibility layer for [Data.Array.Byte](https://hackage.haskell.org/package/base/docs/Data-Array-Byte.html), providing boxed wrappers for @ByteArray#@ and @MutableByteArray#@ and relevant instances for GHC < 9.4. Include it into your Cabal file:

    > build-depends: base
    > if impl(ghc < 9.4)
    >   build-depends: data-array-byte

    and then @import Data.Array.Byte@ unconditionally.

category:             Compatibility
abi:                  b943df61c47197e9dc6714559eded5ea
exposed:              True
exposed-modules:      Data.Array.Byte
import-dirs:          /usr/lib/ghc-9.2.8/site-local/data-array-byte-0.1.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/data-array-byte-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-array-byte
hs-libraries:         HSdata-array-byte-0.1.0.1-71m0qUbz0GPK2XPFn43oUy
depends:
    base-4.16.4.0 deepseq-1.4.6.1 template-haskell-2.18.0.0

haddock-interfaces:
    /usr/share/doc/haskell-data-array-byte/html/data-array-byte.haddock

haddock-html:         /usr/share/doc/haskell-data-array-byte/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
